@@ -9,7 +9,9 @@ from ._categories import CATEGORIES
 from ._gui import Assistant
 from ._gui._category_widget import make_gui_for_category
 from ._statistics_of_labeled_pixels import statistics_of_labeled_pixels
-from ._convert_to_numpy import convert_to_numpy, convert_to_2d_timelapse
+from ._convert_to_numpy import convert_to_numpy, convert_to_2d_timelapse, make_labels_editable, \
+    reset_brightness_contrast, auto_brightness_contrast, split_stack, auto_brightness_contrast_all_images, \
+    set_voxel_size, set_voxel_size_of_all_layers
 from ._categories import attach_tooltips
 
 @napari_hook_implementation
@@ -28,9 +30,21 @@ def napari_provide_sample_data():
         "Lund": data / "Lund_000500_resampled-cropped.tif",
         "CalibZAPWfixed": data / "CalibZAPWfixed_000154_max.tif",
         "Sonneberg": data / "Sonneberg100_Resampled_RotY-40_MaxZ.tif",
+        "Haase_MRT_tfl3d1": "https://zenodo.org/record/5090508/files/Haase_MRT_tfl3d1.tif?download=1",
     }
 
 
 @napari_hook_implementation
 def napari_experimental_provide_function():
-    return [statistics_of_labeled_pixels, convert_to_numpy, convert_to_2d_timelapse]
+    return [
+        statistics_of_labeled_pixels,
+        make_labels_editable,
+        auto_brightness_contrast,
+        auto_brightness_contrast_all_images,
+        reset_brightness_contrast,
+        split_stack,
+        set_voxel_size,
+        set_voxel_size_of_all_layers,
+        convert_to_numpy,
+        convert_to_2d_timelapse
+    ]
